@@ -43,16 +43,17 @@ remap_keys("space", " ")
 remap_keys("ctrl_space", "ctrl_ ")
 remap_keys("alt_space", "alt_ ")
 remap_keys("ctrl_alt_space", "ctrl_alt_ ")
+remap_keys("shift_tab", "shift_backtab")
 remap_keys("before:space", "before: ")
 remap_keys("before:ctrl_space", "before:ctrl_ ")
 remap_keys("before:alt_space", "before:alt_ ")
 remap_keys("before:ctrl_alt_space", "before:ctrl_alt_ ")
+remap_keys("before:shift_tab", "before:shift_backtab")
 
 -- Show warning if any plugins weren't able to be loaded
 if plugin_issues then
     print("Various plug-ins failed to load")
-    print("You may download these plug-ins from the ox git repository (in the plugins folder)")
-    print("https://github.com/curlpipe/ox")
+    print("You may download these plug-ins by running the command `plugin install [plugin_name]`")
     print("")
     print("Alternatively, you may silence these warnings\nby removing the load_plugin() lines in your configuration file\nfor the missing plug-ins that are listed above")
 end
